@@ -22,6 +22,7 @@ package org.apache.spark.k8s.operator.utils;
 import java.io.PrintWriter;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.List;
 
 import lombok.Builder;
@@ -45,6 +46,10 @@ public class DocTable {
     rows.add(row);
   }
 
+  public void sort() {
+    rows.sort(Comparator.comparing(list -> list.get(0)));
+  }
+
   public void flush(PrintWriter writer) {
     writer.println(joinRow(headers));
     writer.println(joinRow(Collections.nCopies(columns, HEADER_SEPARATOR)));
