@@ -27,7 +27,8 @@ import java.util.Map;
 import java.util.Properties;
 
 import lombok.extern.slf4j.Slf4j;
-import org.apache.commons.lang3.StringUtils;
+
+import org.apache.spark.k8s.operator.utils.StringUtils;
 
 /**
  * Loads ConfigOption from properties file. In addition, loads hot properties override from config
@@ -59,6 +60,21 @@ public class SparkOperatorConfManager {
     initialize();
   }
 
+  /**
+   * Returns all properties.
+   *
+   * @return a Properties instance contains all properties.
+   */
+  public Properties getAll() {
+    synchronized (this) {
+      Properties properties = new Properties();
+      properties.putAll(initialConfig);
+      properties.putAll(metricsConfig);
+      properties.putAll(configOverrides);
+      return properties;
+    }
+  }
+
   /**
    * Returns the current value for a given configuration key, considering dynamic overrides.
    *
