@@ -24,9 +24,8 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.Properties;
 
-import org.apache.commons.lang3.StringUtils;
-
 import org.apache.spark.k8s.operator.config.SparkOperatorConfManager;
+import org.apache.spark.k8s.operator.utils.StringUtils;
 
 /** Factory for MetricsSystem. */
 public final class MetricsSystemFactory {
