@@ -24,7 +24,6 @@ import static org.apache.spark.k8s.operator.utils.ProbeUtil.sendMessage;
 
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
@@ -41,9 +40,9 @@ import com.sun.net.httpserver.HttpHandler;
 import jakarta.servlet.http.HttpServletRequest;
 import lombok.Getter;
 import lombok.extern.slf4j.Slf4j;
-import org.apache.commons.lang3.StringUtils;
 
 import org.apache.spark.k8s.operator.config.SparkOperatorConf;
+import org.apache.spark.k8s.operator.utils.StringUtils;
 import org.apache.spark.metrics.sink.PrometheusServlet;
 
 /** Serves as simple Prometheus sink (pull model), presenting metrics snapshot as HttpHandler. */
@@ -94,7 +93,7 @@ public class PrometheusPullModelHandler extends PrometheusServlet implements Htt
           exchange,
           HTTP_OK,
           formatMetricsSnapshot(),
-          Map.of("Content-Type", Collections.singletonList("text/plain;version=0.0.4")));
+          Map.of("Content-Type", List.of("text/plain;version=0.0.4")));
     } else {
       HttpServletRequest httpServletRequest = null;
       String value = getMetricsSnapshot(httpServletRequest);
@@ -102,7 +101,7 @@ public class PrometheusPullModelHandler extends PrometheusServlet implements Htt
           exchange,
           HTTP_OK,
           String.join("\n", filterNonEmptyRecords(value)),
-          Map.of("Content-Type", Collections.singletonList("text/plain;version=0.0.4")));
+          Map.of("Content-Type", List.of("text/plain;version=0.0.4")));
     }
   }
 
