@@ -22,7 +22,6 @@ package org.apache.spark.k8s.operator.metrics.source;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.util.Arrays;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -66,7 +65,7 @@ class KubernetesMetricsInterceptorTest {
   @Order(1)
   void testMetricsEnabled() {
     KubernetesMetricsInterceptor metricsInterceptor = new KubernetesMetricsInterceptor();
-    List<Interceptor> interceptors = Collections.singletonList(metricsInterceptor);
+    List<Interceptor> interceptors = List.of(metricsInterceptor);
     try (KubernetesClient client =
         KubernetesClientFactory.buildKubernetesClient(
             interceptors, kubernetesClient.getConfiguration())) {
@@ -95,9 +94,9 @@ class KubernetesMetricsInterceptorTest {
           .forEach(
               name -> {
                 Meter metric = (Meter) metrics2.get(name);
-                Assertions.assertEquals(metric.getCount(), 1);
+                Assertions.assertEquals(1, metric.getCount());
               });
-      Assertions.assertEquals(((Meter) metrics2.get("http.request")).getCount(), 2);
+      Assertions.assertEquals(2, ((Meter) metrics2.get("http.request")).getCount());
       client.resource(sparkApplication).delete();
     }
   }
@@ -106,7 +105,7 @@ class KubernetesMetricsInterceptorTest {
   @Order(2)
   void testWhenKubernetesServerNotWorking() {
     KubernetesMetricsInterceptor metricsInterceptor = new KubernetesMetricsInterceptor();
-    List<Interceptor> interceptors = Collections.singletonList(metricsInterceptor);
+    List<Interceptor> interceptors = List.of(metricsInterceptor);
     try (KubernetesClient client =
         KubernetesClientFactory.buildKubernetesClient(
             interceptors, kubernetesClient.getConfiguration())) {
