@@ -19,16 +19,17 @@
 
 package org.apache.spark.k8s.operator;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
+
 import java.math.BigInteger;
+import java.security.MessageDigest;
+import java.security.NoSuchAlgorithmException;
 import java.util.List;
 import java.util.Map;
 
 import scala.Option;
 
 import io.fabric8.kubernetes.client.KubernetesClient;
-import org.apache.commons.codec.digest.DigestUtils;
-import org.apache.commons.collections4.MapUtils;
-import org.apache.commons.lang3.StringUtils;
 
 import org.apache.spark.SparkConf;
 import org.apache.spark.deploy.k8s.KubernetesDriverSpec;
@@ -40,7 +41,9 @@ import org.apache.spark.deploy.k8s.submit.RMainAppResource;
 import org.apache.spark.k8s.operator.spec.ApplicationSpec;
 import org.apache.spark.k8s.operator.spec.ConfigMapSpec;
 import org.apache.spark.k8s.operator.spec.DriverServiceIngressSpec;
+import org.apache.spark.k8s.operator.spec.RuntimeVersions;
 import org.apache.spark.k8s.operator.utils.ModelUtils;
+import org.apache.spark.k8s.operator.utils.StringUtils;
 
 /**
  * Similar to org.apache.spark.deploy.k8s.submit.KubernetesClientApplication. This reads args from
@@ -68,6 +71,17 @@ public class SparkAppSubmissionWorker {
   /** Property name for the Spark master URL prefix. */
   public static final String MASTER_URL_PREFIX_PROPS_NAME = "spark.master.url.prefix";
 
+  /** SHA256 Message Digest when generating hash-based identifier. */
+  private static final ThreadLocal<MessageDigest> SHA_256_THREAD_LOCAL =
+      ThreadLocal.withInitial(
+          () -> {
+            try {
+              return MessageDigest.getInstance("SHA-256");
+            } catch (NoSuchAlgorithmException e) {
+              throw new UnsupportedOperationException(e);
+            }
+          });
+
   /**
    * Build secondary resource spec for given app with Spark developer API, with defaults / overrides
    * as:
@@ -110,13 +124,19 @@ public class SparkAppSubmissionWorker {
   protected SparkAppDriverConf buildDriverConf(
       SparkApplication app, Map<String, String> confOverrides) {
     ApplicationSpec applicationSpec = app.getSpec();
+    RuntimeVersions versions = applicationSpec.getRuntimeVersions();
+    String sparkVersion = (versions != null) ? versions.getSparkVersion() : "UNKNOWN";
     SparkConf effectiveSparkConf = new SparkConf();
-    if (MapUtils.isNotEmpty(applicationSpec.getSparkConf())) {
+    if (!applicationSpec.getSparkConf().isEmpty()) {
       for (String confKey : applicationSpec.getSparkConf().keySet()) {
-        effectiveSparkConf.set(confKey, applicationSpec.getSparkConf().get(confKey));
+        String value = applicationSpec.getSparkConf().get(confKey);
+        if (confKey.startsWith("spark.kubernetes.") && confKey.endsWith("container.image")) {
+          value = value.replace("{{SPARK_VERSION}}", sparkVersion);
+        }
+        effectiveSparkConf.set(confKey, value);
       }
     }
-    if (MapUtils.isNotEmpty(confOverrides)) {
+    if (!confOverrides.isEmpty()) {
       for (Map.Entry<String, String> entry : confOverrides.entrySet()) {
         effectiveSparkConf.set(entry.getKey(), entry.getValue());
       }
@@ -126,6 +146,12 @@ public class SparkAppSubmissionWorker {
     if (StringUtils.isNotEmpty(applicationSpec.getJars())) {
       primaryResource = new JavaMainAppResource(Option.apply(applicationSpec.getJars()));
       effectiveSparkConf.setIfMissing("spark.jars", applicationSpec.getJars());
+    } else if ("org.apache.spark.deploy.PythonRunner".equals(applicationSpec.getMainClass())) {
+      String[] files = applicationSpec.getPyFiles().split(",", 2);
+      primaryResource = new PythonMainAppResource(files[0]);
+      if (files.length > 1 && !files[1].isBlank()) {
+        effectiveSparkConf.setIfMissing("spark.submit.pyFiles", files[1]);
+      }
     } else if (StringUtils.isNotEmpty(applicationSpec.getPyFiles())) {
       primaryResource = new PythonMainAppResource(applicationSpec.getPyFiles());
       effectiveSparkConf.setIfMissing("spark.submit.pyFiles", applicationSpec.getPyFiles());
@@ -141,6 +167,7 @@ public class SparkAppSubmissionWorker {
     effectiveSparkConf.setIfMissing("spark.app.id", appId);
     return SparkAppDriverConf.create(
         effectiveSparkConf,
+        sparkVersion,
         effectiveSparkConf.getAppId(),
         primaryResource,
         applicationSpec.getMainClass(),
@@ -202,8 +229,9 @@ public class SparkAppSubmissionWorker {
    * @return The generated hash-based ID.
    */
   public static String generateHashBasedId(final String prefix, final String... identifiers) {
+    final MessageDigest sha256 = SHA_256_THREAD_LOCAL.get();
     String sha256Hash =
-        new BigInteger(1, DigestUtils.sha256(String.join("/", identifiers)))
+        new BigInteger(1, sha256.digest(String.join("/", identifiers).getBytes(UTF_8)))
             .toString(DEFAULT_ENCODE_BASE);
     String truncatedIdentifiersHash =
         sha256Hash.substring(0, DEFAULT_HASH_BASED_IDENTIFIER_LENGTH_LIMIT);
