@@ -21,9 +21,8 @@ package org.apache.spark.k8s.operator;
 
 import java.util.Map;
 
-import org.apache.commons.collections4.MapUtils;
-
 import org.apache.spark.SparkConf;
+import org.apache.spark.k8s.operator.spec.RuntimeVersions;
 
 /** Worker for submitting Spark clusters. */
 public class SparkClusterSubmissionWorker {
@@ -36,16 +35,23 @@ public class SparkClusterSubmissionWorker {
    */
   public SparkClusterResourceSpec getResourceSpec(
       SparkCluster cluster, Map<String, String> confOverrides) {
+    RuntimeVersions versions = cluster.getSpec().getRuntimeVersions();
+    String sparkVersion = (versions != null) ? versions.getSparkVersion() : "UNKNOWN";
     SparkConf effectiveSparkConf = new SparkConf();
 
     Map<String, String> confFromSpec = cluster.getSpec().getSparkConf();
-    if (MapUtils.isNotEmpty(confFromSpec)) {
+    if (!confFromSpec.isEmpty()) {
       for (Map.Entry<String, String> entry : confFromSpec.entrySet()) {
         effectiveSparkConf.set(entry.getKey(), entry.getValue());
+        String value = entry.getValue();
+        if ("spark.kubernetes.container.image".equals(entry.getKey())) {
+          value = value.replace("{{SPARK_VERSION}}", sparkVersion);
+        }
+        effectiveSparkConf.set(entry.getKey(), value);
       }
     }
 
-    if (MapUtils.isNotEmpty(confOverrides)) {
+    if (!confOverrides.isEmpty()) {
       for (Map.Entry<String, String> entry : confOverrides.entrySet()) {
         effectiveSparkConf.set(entry.getKey(), entry.getValue());
       }
